summaryrefslogtreecommitdiff
path: root/http/config.go
diff options
context:
space:
mode:
Diffstat (limited to 'http/config.go')
-rw-r--r--http/config.go10
1 files changed, 2 insertions, 8 deletions
diff --git a/http/config.go b/http/config.go
index efcaae30..abb14d9a 100644
--- a/http/config.go
+++ b/http/config.go
@@ -2,7 +2,6 @@ package http
import (
"github.com/spiral/roadrunner"
- "fmt"
)
// Configures RoadRunner HTTP server.
@@ -10,8 +9,8 @@ type Config struct {
// Enable enables http service.
Enable bool
- // Host and port to handle as http server.
- Host, Port string
+ // Address and port to handle as http server.
+ Address string
// MaxRequest specified max size for payload body in bytes, set 0 to unlimited.
MaxRequest int64
@@ -27,8 +26,3 @@ type Config struct {
func (cfg *Config) Valid() error {
return nil
}
-
-// httpAddr returns prepared http listen address.
-func (cfg *Config) httpAddr() string {
- return fmt.Sprintf("%s:%v", cfg.Host, cfg.Port)
-}